.. _spkg_soupsieve:

soupsieve: Modern CSS selector implementation for Beautiful Soup
==========================================================================

Description
-----------

Modern CSS selector implementation for Beautiful Soup

License
-------

Upstream Contact
----------------

https://pypi.org/project/soupsieve/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

package-version.txt::

    2.5

version_requirements.txt::

    soupsieve


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install soupsieve 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install python3-soupsieve 



If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure``
will check if the system package can be used.

